LabeledShapeDrawable class abstract interface

Common interface for one- and two-dimensional labeled shapes.

Implemented types
Implementers

Properties

assistPaints Map<ObjectDrawableAssist, Paint>
The paint to be used for each assist type.
finalinherited
assists Set<ObjectDrawableAssist>
The current assist lines the object has.
finalinherited
erasable bool
Whether free-style erasing can affect this drawable.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
hidden bool
Whether the drawable is hidden or not.
finalinherited
isHidden bool
no setterinherited
isNotHidden bool
no setterinherited
label ShapeLabel
The label drawn over the shape.
no setter
locked bool
Defines if the object drawable is locked or not. If it is locked, it won't be movable, scalable or re-sizable using the UI.
finalinherited
min_scale double
no setterinherited
paint Paint
The paint to be used for the shape drawable.
getter/setter pairinherited
position Offset
The location of the object to be painted.
finalinherited
rotationAngle double
The rotation of the object to be painted in radians.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scale double
The scale of the object to be painted.
finalinherited
shape ShapeDrawable
The shape used for drawing.
no setter

Methods

copyWith({bool? hidden, Set<ObjectDrawableAssist>? assists, Offset? position, double? rotation, double? scale, Paint? paint, bool? locked}) ShapeDrawable
Creates a copy of this but with the given fields replaced with the new values.
inherited
copyWithLabel(ShapeLabel label) LabeledShapeDrawable
Returns a copy with label.
draw(Canvas canvas, Size size) → void
Draws the object on the provided canvas of size size.
inherited
drawAssists(Canvas canvas, Size size) → void
Draws any assist lines that the object has on canvas with size.
inherited
drawObject(Canvas canvas, Size size) → void
Abstract method to draw the object.
inherited
getSize({double minWidth = 0.0, double maxWidth = double.infinity}) Size
Abstract method to get the size of the rendered object.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited