flutter_painter_pure library

The Flutter Painter library without extensions.

From this library, you can access all the APIs of Flutter Painter excluding the extensions.

Classes

AngleDrawable
A two-ray angle with an arc showing its clockwise sweep.
AngleFactory
Creates AngleDrawables whose sweep is defined by the drawing gesture.
ArrowDrawable
A drawable of a simple arrow shape.
ArrowFactory
A ArrowDrawable factory.
BackgroundDrawable
Abstract class to define a drawable object to be used as a background.
ColorBackgroundDrawable
Drawable to use a color as a background.
DoubleArrowDrawable
A drawable of a arrow on both side shape.
DoubleArrowFactory
A DoubleArrowDrawable factory.
Drawable
Abstract class to define a drawable object.
DrawableJsonAdapter
Converts an application-specific Drawable to and from JSON data.
DrawableJsonCodec
A versioned JSON codec for Flutter Painter drawables.
EraseDrawable
Free-style Erase Drawable .
FloodFillDrawable
A compact raster-derived flood fill rendered in painter coordinates.
FloodFillSpan
One inclusive horizontal pixel span produced by a flood fill.
FlutterPainter
Widget that allows user to draw on it
FreeStyleDrawable
Free-style Drawable (hand scribble).
FreeStyleFactory<T extends PathDrawable>
Creates custom PathDrawables for free-style drawing gestures.
FreeStyleSettings
Represents settings used to create and draw free-style drawables.
ImageBackgroundDrawable
Drawable to use an image as a background.
ImageDrawable
A drawable of an image as an object.
LabeledShapeDrawable
Common interface for one- and two-dimensional labeled shapes.
LabeledShapeFactory
Wraps any sized ShapeFactory with a centered text label.
LabeledSized1DShapeDrawable
A labeled wrapper for a Sized1DDrawable shape.
LabeledSized2DShapeDrawable
A labeled wrapper for a Sized2DDrawable shape.
LineDrawable
A drawable of a simple line shape.
LineFactory
A LineDrawable factory.
ObjectDrawable
An abstract drawable that can be moved and rotated and scaled.
ObjectGroupDrawable
A transformable group of object drawables.
ObjectLayoutAssistSettings
Represents settings that control the behavior of layout assist for objects.
ObjectSettings
Represents settings used to control object drawables in the UI
OvalDrawable
A drawable of an oval.
OvalFactory
A OvalDrawable factory.
PainterController
Controller used to control a FlutterPainter widget.
PainterControllerValue
The current paint mode, drawables and background values of a FlutterPainter widget.
PainterSettings
Represents all the settings used to create and draw drawables.
PathDrawable
Free-style Drawable (hand scribble).
RectangleDrawable
A drawable of a rectangle with a radius.
RectangleFactory
A RectangleDrawable factory.
ScaleSettings
Represents the settings of scaling the FlutterPainter.
ShapeDrawable
Abstract class representing a drawable of a shape.
ShapeFactory<T extends ShapeDrawable>
An abstract class that defines an object that can create shape drawables.
ShapeLabel
Text and background styling for a label drawn on a shape.
ShapeSettings
Represents settings used to control shape drawables in the UI
TextDrawable
Text Drawable
TextSettings
Represents settings used to create and draw text.
TriangleDrawable
A drawable of an isosceles triangle.
TriangleFactory
A TriangleDrawable factory.

Enums

FreeStyleMode
Enum representing different states that free-style painting can be.
HapticFeedbackSettings
Represents the possible haptic feedback settings.
ImageDrawableShape
The clipping shape used by an ImageDrawable.
ObjectDrawableAssist
Defines the different types of assist lines objects might have.

Extensions

ColorBackgroundDrawableGetter on Color
An extension on Color to create a background drawable easily.
HapticFeedbackSettingsImpact on HapticFeedbackSettings
An extension to add a method that performs the haptic feedback impact.
ImageBackgroundDrawableGetter on Image
An extension on ui.Image to create a background drawable easily.

Properties

usingHtmlRenderer bool
On native platform, the HTML renderer is never used.
no setter

Typedefs

FreeStyleDrawingCallback = void Function(PathDrawable drawable)
A callback for a free-style PathDrawable drawing lifecycle event.
ObjectEnlargeControlsResolver = bool Function()
ObjectShowScaleRotationControlsResolver = bool Function()