AngleFactory class
Creates AngleDrawables whose sweep is defined by the drawing gesture.
- Inheritance
-
- Object
- ShapeFactory<
AngleDrawable> - AngleFactory
Constructors
- AngleFactory({double startAngle = 0, double initialSweepAngle = math.pi / 4, double arcRadius = 24})
-
Creates an angle factory.
const
Properties
- arcRadius → double
-
The unscaled radius of the arc drawn between the rays.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- initialSweepAngle → double
-
The sweep used before the pointer moves.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- startAngle → double
-
The direction of the first ray in radians.
final
Methods
-
create(
Offset position, [Paint? paint]) → AngleDrawable -
Creates the desired shape drawable.
Inheriting classes must override this method to create the appropriate ShapeDrawable.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited