ObjectGroupDrawable class
A transformable group of object drawables.
The child drawables use coordinates local to the center of the group. Create groups from painter-coordinate drawables with ObjectGroupDrawable.fromDrawables.
- Inheritance
-
- Object
- Drawable
- ObjectDrawable
- ObjectGroupDrawable
Constructors
-
ObjectGroupDrawable.fromDrawables({required Iterable<
ObjectDrawable> drawables, double maxWidth = double.infinity, double rotationAngle = 0, double scale = 1, Set<ObjectDrawableAssist> assists = const <ObjectDrawableAssist>{}, Map<ObjectDrawableAssist, Paint> assistPaints = const <ObjectDrawableAssist, Paint>{}, bool locked = false, }) -
Creates a group from
drawablespositioned in painter coordinates.factory -
ObjectGroupDrawable.fromLocalDrawables({required Iterable<
ObjectDrawable> drawables, required Offset position, double rotationAngle = 0, double scale = 1, Set<ObjectDrawableAssist> assists = const <ObjectDrawableAssist>{}, Map<ObjectDrawableAssist, Paint> assistPaints = const <ObjectDrawableAssist, Paint>{}, bool locked = false, }) -
Creates a group from children already expressed in group-local space.
factory
Properties
-
assistPaints
→ Map<
ObjectDrawableAssist, Paint> -
The paint to be used for each assist type.
finalinherited
-
assists
→ Set<
ObjectDrawableAssist> -
The current assist lines the object has.
finalinherited
-
drawables
→ List<
ObjectDrawable> -
The objects contained by this group, in paint order.
final
- erasable → bool
-
Whether free-style erasing can affect this drawable.
no setteroverride
- hashCode → int
-
The hash code for this object.
no setterinherited
-
Whether the drawable is hidden or not.
finalinherited
- isHidden → bool
-
no setterinherited
- isNotHidden → bool
-
no setterinherited
- locked → bool
-
Defines if the object drawable is locked or not.
If it is locked, it won't be movable, scalable or re-sizable using the UI.
finalinherited
- min_scale → double
-
no setterinherited
- position → Offset
-
The location of the object to be painted.
finalinherited
- rotationAngle → double
-
The rotation of the object to be painted in radians.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scale → double
-
The scale of the object to be painted.
finalinherited
Methods
-
copyWith(
{Set< ObjectDrawableAssist> ? assists, Map<ObjectDrawableAssist, Paint> ? assistPaints, Offset? position, double? rotation, double? scale, bool? locked}) → ObjectGroupDrawable -
Compares two ObjectDrawables for equality.
Creates a copy of this but with the given fields replaced with the new values.
override
-
draw(
Canvas canvas, Size size) → void -
Draws the object on the provided
canvasof sizesize.override -
drawAssists(
Canvas canvas, Size size) → void -
Draws any assist lines that the object has on
canvaswithsize.inherited -
drawObject(
Canvas canvas, Size size) → void -
Abstract method to draw the object.
override
-
getSize(
{double minWidth = 0.0, double maxWidth = double.infinity}) → Size -
Abstract method to get the size of the rendered object.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
toWorldDrawables(
) → List< ObjectDrawable> - Returns the children transformed back into painter coordinates.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited